@@ -50,6 +50,9 @@ def date_range_params(period_config, comparison, period, reference_date):
     if period_config == "ytd":
         start_date = today.strftime("%Y-01-01")
         end_date = today.strftime("%Y-%m-%d")
+    elif period_config == "year":
+        start_date = today.strftime("%Y-01-01")
+        end_date = (today + relativedelta(years=1)).strftime("%Y-01-01")
     elif period_config == "lytd":
         start_date = (today + relativedelta(years=-1)).strftime("%Y-01-01")
         end_date = (today + relativedelta(years=-1)).strftime("%Y-%m-%d")
@@ -73,8 +76,13 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = datetime.date(today.year, month_quarter, 1)
         start_date = start_date.strftime("%Y-%m-%d")
         end_date = (today + relativedelta(months=-3)).strftime("%Y-%m-%d")
-
-
+    elif period_config == "quarter":
+        month = today.month
+        month_quarter = month - (month - 1) % 3
+        start_date = datetime.date(today.year, month_quarter, 1)
+        end_date = start_date + relativedelta(months=3)
+        start_date = start_date.strftime("%Y-%m-%d")
+        end_date = end_date.strftime("%Y-%m-%d")
 
     elif period_config == "yesterday":
         start_date = (today + relativedelta(days=-1)).strftime("%Y-%m-%d")
@@ -120,7 +128,13 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
         end_date = (today + relativedelta(years=-1)).strftime("%Y-%m-%d")
 
+    elif period_config == 'wtd':
+        start_date = (today + relativedelta(days=-today.weekday())).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d")
 
+    elif period_config == 'lwtd':
+        start_date = (today + relativedelta(days=-7) + relativedelta(days=-today.weekday())).strftime("%Y-%m-%d")
+        end_date = (today + relativedelta(days=-7)).strftime("%Y-%m-%d")
 
     else:
         return {}
@@ -284,12 +298,7 @@ class DataSource:
 
         if self.layer_type != "export" and query_config.get("create_clause") != "from_query":
             if query_config.get("create_clause") == "view":
-                query_string = """
-                drop view if exists {{ table_name }};
-                create view {{ table_name }} as (
-                %s
-                );
-                """ % query_string
+                query_string = self.dbstream.build_pydatasource_view(query_string)
             elif query_config.get("drop_clause") == "cascade":
                 query_string = self.dbstream.build_pydatasource_table_cascade(query_string)
             else:
